@@ -114,21 +114,21 @@ INSTALLED_APPS = (
     'tagging',
     'tinymce',
     'emencia.django.newsletter',
-    'Theophrastus.editor',
-    'Theophrastus.statistics',
-    'Theophrastus.cloud',
-    'Theophrastus.newsletter_extension',
-    'Theophrastus.document',
+    # 'Theophrastus.editor',
+    # 'Theophrastus.statistics',
+    # 'Theophrastus.cloud',
+    # 'Theophrastus.newsletter_extension',
+    # 'Theophrastus.document',
     # 'Theophrastus.integration',
-    'Theophrastus.api',
+    # 'Theophrastus.api',
     # If your want do translate, you need to enable these:
-    #'editor',
-    #'statistics',
-    #'cloud',
-    #'newsletter_extension',
-    #'document',
-    #'integration',
-    #'api',
+    # 'editor',
+    # 'statistics',
+    # 'cloud',
+    # 'newsletter_extension',
+    # 'document',
+    'integration',
+    # 'api',
 )
 
 # SECURITY WARNING: keep the secret key used in production secret!
