@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 10380 2017-10-17 08:05:05Z David $
+# $Id: admin.py 10449 2017-11-07 06:22:13Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-10-17 16:05:05 +0800 (Tue, 17 Oct 2017) $
-# $Revision: 10380 $
+# $Date: 2017-11-07 14:22:13 +0800 (Tue, 07 Nov 2017) $
+# $Revision: 10449 $
 
 from django import forms
 from django.contrib import admin
@@ -32,8 +32,22 @@ class NewsletterTinyMCEForm(forms.ModelForm):
 
     def __init__(self, *args, **kwargs):
         
-        sender = Newsletter.objects.all().order_by('-id')[0].header_sender
-        reply = Newsletter.objects.all().order_by('-id')[0].header_reply
+        newsletterObj = Newsletter.objects.all().order_by('-id')
+
+        if newsletterObj:
+            sender = newsletterObj[0].header_sender
+            reply = newsletterObj[0].header_reply
+        else:
+            sender = getattr(
+                settings,
+                'NEWSLETTER_DEFAULT_HEADER_SENDER',
+                "Nuwa<service@tracedig.com>"
+            )
+            reply = getattr(
+                settings,
+                'NEWSLETTER_DEFAULT_HEADER_REPLY',
+                "Nuwa<service@tracedig.com>"
+            )
 
         super(NewsletterTinyMCEForm, self).__init__(*args, **kwargs)
         self.fields['header_sender'].initial = sender
