@@ -21,10 +21,10 @@ from django.utils.translation import ugettext as _
 
 from Iuppiter.Model import BaseModelMixin
 
-from Theophrastus.models import Newsletter
+# from Theophrastus.models import Newsletter
+from emencia.django.newsletter.models import Newsletter
 
-
-class Group(models.Model, BaseModelMixin):
+class Group(models.Model):
     name = models.CharField(_('name'), max_length=255)
 
     newsletters = models.ManyToManyField(
@@ -77,7 +77,7 @@ class Group(models.Model, BaseModelMixin):
         verbose_name = _('group')
         verbose_name_plural = _('groups')
 
-class App(models.Model, BaseModelMixin):
+class App(models.Model):
     name = models.CharField(max_length=255, verbose_name=_('Name'))
     user = models.ForeignKey(User, verbose_name=_('User'))
     groups = models.ManyToManyField(Group, related_name='groups', null=True)
@@ -91,7 +91,7 @@ class App(models.Model, BaseModelMixin):
         verbose_name = _('app')
         verbose_name_plural = _('apps')
 
-class GroupMappingTable(models.Model, BaseModelMixin):
+class GroupMappingTable(models.Model):
 
     KEYWORD = 0
     REGULAR_EXPRESSION = 1
